@@ -76,6 +76,13 @@ options:
                 description:
                     - Subresource name.
                 type: str
+    tags:
+        description:
+            - A dictionary of tags to filter on.
+            - Each key-value pair in the dictionary specifies a tag name and its value to filter on differente resources.
+        type: dict
+        required: false
+        default: {}
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -98,6 +105,14 @@ EXAMPLES = '''
   azure_rm_resource_info:
     resource_group: "{{ resource_group }}"
     resource_type: resources
+
+- name: Get all snapshots of all resource groups of a subscription but filtering with two tags.
+  azure_rm_resource_info:
+    provider: compute
+    resource_type: snapshots
+    tags:
+      enviroment: dev
+      department: hr
 '''
 
 RETURN = '''
@@ -346,7 +361,8 @@ class AzureRMResourceInfo(AzureRMModuleBase):
             ),
             api_version=dict(
                 type='str'
-            )
+            ),
+            tags=dict(type='dict', default={})
         )
         # store the results of the module operation
         self.results = dict(
@@ -363,14 +379,10 @@ class AzureRMResourceInfo(AzureRMModuleBase):
         super(AzureRMResourceInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=False)
 
     def exec_module(self, **kwargs):
-        is_old_facts = self.module._name == 'azure_rm_resource_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_resource_facts' module has been renamed to 'azure_rm_resource_info'", version=(2.9, ))
 
         for key in self.module_arg_spec:
             setattr(self, key, kwargs[key])
         self.mgmt_client = self.get_mgmt_svc_client(GenericRestClient,
-                                                    is_track2=True,
                                                     base_url=self._cloud_environment.endpoints.resource_manager)
 
         if self.url is None:
@@ -439,17 +451,27 @@ class AzureRMResourceInfo(AzureRMModuleBase):
                 query_parameters['skiptoken'] = skiptoken
             response = self.mgmt_client.query(self.url, self.method, query_parameters, header_parameters, None, [200, 404], 0, 0)
             try:
-                response = json.loads(response.body())
-                if isinstance(response, dict):
-                    if response.get('value'):
-                        self.results['response'] = self.results['response'] + response['value']
-                        skiptoken = response.get('nextLink')
-                    else:
-                        self.results['response'] = self.results['response'] + [response]
+                if isinstance(response.body(), bytes) and bool(response.body().decode()) is False:
+                    self.results['status_code'] = response.status_code
+                else:
+                    self.results['status_code'] = response.status_code
+                    response = json.loads(response.body())
+                    if isinstance(response, dict):
+                        if response.get('value'):
+                            self.results['response'] = self.results['response'] + response['value']
+                            skiptoken = response.get('nextLink')
+                        else:
+                            self.results['response'] = self.results['response'] + [response]
             except Exception as e:
                 self.fail('Failed to parse response: ' + str(e))
             if not skiptoken:
                 break
+        if kwargs['tags']:
+            filtered_response = []
+            for resource in self.results['response']:
+                if all(resource.get('tags', {}).get(tag_key) == tag_value for tag_key, tag_value in kwargs['tags'].items()):
+                    filtered_response.append(resource)
+            self.results['response'] = filtered_response
         return self.results
 
 
