@@ -8,8 +8,7 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: api_modify
 author:
   - "Felix Fontein (@felixfontein)"
@@ -17,17 +16,17 @@ short_description: Modify data at paths with API
 version_added: 2.2.0
 description:
   - Allows to modify information for a path using the API.
-  - Use the M(community.routeros.api_find_and_modify) module to modify one or multiple entries in a controlled way
-    depending on some search conditions.
+  - Use the M(community.routeros.api_find_and_modify) module to modify one or multiple entries in a controlled way depending
+    on some search conditions.
   - To make a backup of a path that can be restored with this module, use the M(community.routeros.api_info) module.
   - The module ignores dynamic and builtin entries.
-  - B(Note) that this module is still heavily in development, and only supports B(some) paths.
-    If you want to support new paths, or think you found problems with existing paths, please first
-    L(create an issue in the community.routeros Issue Tracker,https://github.com/ansible-collections/community.routeros/issues/).
+  - B(Note) that this module is still heavily in development, and only supports B(some) paths. If you want to support new
+    paths, or think you found problems with existing paths, please first L(create an issue in the community.routeros Issue
+    Tracker,https://github.com/ansible-collections/community.routeros/issues/).
 notes:
-  - If write-only fields are present in the path, the module is B(not idempotent) in a strict sense,
-    since it is not able to verify the current value of these fields. The behavior the module should
-    assume can be controlled with the O(handle_write_only) option.
+  - If write-only fields are present in the path, the module is B(not idempotent) in a strict sense, since it is not able
+    to verify the current value of these fields. The behavior the module should assume can be controlled with the O(handle_write_only)
+    option.
 requirements:
   - Needs L(ordereddict,https://pypi.org/project/ordereddict) for Python 2.6
 extends_documentation_fragment:
@@ -43,233 +42,244 @@ attributes:
   platform:
     support: full
     platforms: RouterOS
+  idempotent:
+    support: full
 options:
   path:
     description:
       - Path to query.
-      - An example value is V(ip address). This is equivalent to running modification commands in C(/ip address) in the RouterOS CLI.
+      - An example value is V(ip address). This is equivalent to running modification commands in C(/ip address) in the RouterOS
+        CLI.
     required: true
     type: str
     choices:
     # BEGIN PATH LIST
-        - caps-man aaa
-        - caps-man access-list
-        - caps-man channel
-        - caps-man configuration
-        - caps-man datapath
-        - caps-man manager
-        - caps-man manager interface
-        - caps-man provisioning
-        - caps-man security
-        - certificate settings
-        - interface bonding
-        - interface bridge
-        - interface bridge mlag
-        - interface bridge port
-        - interface bridge port-controller
-        - interface bridge port-extender
-        - interface bridge settings
-        - interface bridge vlan
-        - interface detect-internet
-        - interface eoip
-        - interface ethernet
-        - interface ethernet poe
-        - interface ethernet switch
-        - interface ethernet switch port
-        - interface gre
-        - interface gre6
-        - interface l2tp-client
-        - interface l2tp-server server
-        - interface list
-        - interface list member
-        - interface ovpn-client
-        - interface ovpn-server server
-        - interface ppp-client
-        - interface pppoe-client
-        - interface pppoe-server server
-        - interface pptp-server server
-        - interface sstp-server server
-        - interface vlan
-        - interface vrrp
-        - interface wifi
-        - interface wifi aaa
-        - interface wifi access-list
-        - interface wifi cap
-        - interface wifi capsman
-        - interface wifi channel
-        - interface wifi configuration
-        - interface wifi datapath
-        - interface wifi interworking
-        - interface wifi provisioning
-        - interface wifi security
-        - interface wifi steering
-        - interface wifiwave2
-        - interface wifiwave2 aaa
-        - interface wifiwave2 access-list
-        - interface wifiwave2 cap
-        - interface wifiwave2 capsman
-        - interface wifiwave2 channel
-        - interface wifiwave2 configuration
-        - interface wifiwave2 datapath
-        - interface wifiwave2 interworking
-        - interface wifiwave2 provisioning
-        - interface wifiwave2 security
-        - interface wifiwave2 steering
-        - interface wireguard
-        - interface wireguard peers
-        - interface wireless
-        - interface wireless align
-        - interface wireless cap
-        - interface wireless security-profiles
-        - interface wireless sniffer
-        - interface wireless snooper
-        - iot modbus
-        - ip accounting
-        - ip accounting web-access
-        - ip address
-        - ip arp
-        - ip cloud
-        - ip cloud advanced
-        - ip dhcp-client
-        - ip dhcp-client option
-        - ip dhcp-relay
-        - ip dhcp-server
-        - ip dhcp-server config
-        - ip dhcp-server lease
-        - ip dhcp-server matcher
-        - ip dhcp-server network
-        - ip dhcp-server option
-        - ip dhcp-server option sets
-        - ip dns
-        - ip dns adlist
-        - ip dns static
-        - ip firewall address-list
-        - ip firewall connection tracking
-        - ip firewall filter
-        - ip firewall layer7-protocol
-        - ip firewall mangle
-        - ip firewall nat
-        - ip firewall raw
-        - ip firewall service-port
-        - ip hotspot service-port
-        - ip ipsec identity
-        - ip ipsec peer
-        - ip ipsec policy
-        - ip ipsec profile
-        - ip ipsec proposal
-        - ip ipsec settings
-        - ip neighbor discovery-settings
-        - ip pool
-        - ip proxy
-        - ip route
-        - ip route rule
-        - ip route vrf
-        - ip service
-        - ip settings
-        - ip smb
-        - ip socks
-        - ip ssh
-        - ip tftp settings
-        - ip traffic-flow
-        - ip traffic-flow ipfix
-        - ip traffic-flow target
-        - ip upnp
-        - ip upnp interfaces
-        - ip vrf
-        - ipv6 address
-        - ipv6 dhcp-client
-        - ipv6 dhcp-server
-        - ipv6 dhcp-server option
-        - ipv6 firewall address-list
-        - ipv6 firewall filter
-        - ipv6 firewall mangle
-        - ipv6 firewall nat
-        - ipv6 firewall raw
-        - ipv6 nd
-        - ipv6 nd prefix
-        - ipv6 nd prefix default
-        - ipv6 route
-        - ipv6 settings
-        - mpls
-        - mpls interface
-        - mpls ldp
-        - mpls ldp accept-filter
-        - mpls ldp advertise-filter
-        - mpls ldp interface
-        - port firmware
-        - port remote-access
-        - ppp aaa
-        - ppp profile
-        - ppp secret
-        - queue interface
-        - queue simple
-        - queue tree
-        - queue type
-        - radius
-        - radius incoming
-        - routing bgp aggregate
-        - routing bgp connection
-        - routing bgp instance
-        - routing bgp network
-        - routing bgp peer
-        - routing bgp template
-        - routing filter
-        - routing filter num-list
-        - routing filter rule
-        - routing filter select-rule
-        - routing id
-        - routing igmp-proxy
-        - routing igmp-proxy interface
-        - routing mme
-        - routing ospf area
-        - routing ospf area range
-        - routing ospf instance
-        - routing ospf interface-template
-        - routing ospf static-neighbor
-        - routing pimsm instance
-        - routing pimsm interface-template
-        - routing rip
-        - routing ripng
-        - routing rule
-        - routing table
-        - snmp
-        - snmp community
-        - system clock
-        - system clock manual
-        - system health settings
-        - system identity
-        - system leds settings
-        - system logging
-        - system logging action
-        - system note
-        - system ntp client
-        - system ntp client servers
-        - system ntp server
-        - system package update
-        - system resource irq rps
-        - system routerboard settings
-        - system scheduler
-        - system script
-        - system upgrade mirror
-        - system ups
-        - system watchdog
-        - tool bandwidth-server
-        - tool e-mail
-        - tool graphing
-        - tool graphing interface
-        - tool graphing resource
-        - tool mac-server
-        - tool mac-server mac-winbox
-        - tool mac-server ping
-        - tool netwatch
-        - tool romon
-        - tool sms
-        - tool sniffer
-        - tool traffic-generator
-        - user
-        - user aaa
-        - user group
-        - user settings
+      - caps-man aaa
+      - caps-man access-list
+      - caps-man channel
+      - caps-man configuration
+      - caps-man datapath
+      - caps-man manager
+      - caps-man manager interface
+      - caps-man provisioning
+      - caps-man security
+      - certificate settings
+      - interface 6to4
+      - interface bonding
+      - interface bridge
+      - interface bridge mlag
+      - interface bridge port
+      - interface bridge port-controller
+      - interface bridge port-extender
+      - interface bridge settings
+      - interface bridge vlan
+      - interface detect-internet
+      - interface eoip
+      - interface ethernet
+      - interface ethernet poe
+      - interface ethernet switch
+      - interface ethernet switch port
+      - interface ethernet switch port-isolation
+      - interface gre
+      - interface gre6
+      - interface l2tp-client
+      - interface l2tp-server server
+      - interface list
+      - interface list member
+      - interface ovpn-client
+      - interface ovpn-server server
+      - interface ppp-client
+      - interface pppoe-client
+      - interface pppoe-server server
+      - interface pptp-server server
+      - interface sstp-server server
+      - interface vlan
+      - interface vrrp
+      - interface wifi
+      - interface wifi aaa
+      - interface wifi access-list
+      - interface wifi cap
+      - interface wifi capsman
+      - interface wifi channel
+      - interface wifi configuration
+      - interface wifi datapath
+      - interface wifi interworking
+      - interface wifi provisioning
+      - interface wifi security
+      - interface wifi steering
+      - interface wifiwave2
+      - interface wifiwave2 aaa
+      - interface wifiwave2 access-list
+      - interface wifiwave2 cap
+      - interface wifiwave2 capsman
+      - interface wifiwave2 channel
+      - interface wifiwave2 configuration
+      - interface wifiwave2 datapath
+      - interface wifiwave2 interworking
+      - interface wifiwave2 provisioning
+      - interface wifiwave2 security
+      - interface wifiwave2 steering
+      - interface wireguard
+      - interface wireguard peers
+      - interface wireless
+      - interface wireless access-list
+      - interface wireless align
+      - interface wireless cap
+      - interface wireless connect-list
+      - interface wireless security-profiles
+      - interface wireless sniffer
+      - interface wireless snooper
+      - iot modbus
+      - ip accounting
+      - ip accounting web-access
+      - ip address
+      - ip arp
+      - ip cloud
+      - ip cloud advanced
+      - ip dhcp-client
+      - ip dhcp-client option
+      - ip dhcp-relay
+      - ip dhcp-server
+      - ip dhcp-server config
+      - ip dhcp-server lease
+      - ip dhcp-server matcher
+      - ip dhcp-server network
+      - ip dhcp-server option
+      - ip dhcp-server option sets
+      - ip dns
+      - ip dns adlist
+      - ip dns forwarders
+      - ip dns static
+      - ip firewall address-list
+      - ip firewall connection tracking
+      - ip firewall filter
+      - ip firewall layer7-protocol
+      - ip firewall mangle
+      - ip firewall nat
+      - ip firewall raw
+      - ip firewall service-port
+      - ip hotspot service-port
+      - ip ipsec identity
+      - ip ipsec mode-config
+      - ip ipsec peer
+      - ip ipsec policy
+      - ip ipsec profile
+      - ip ipsec proposal
+      - ip ipsec settings
+      - ip neighbor discovery-settings
+      - ip pool
+      - ip proxy
+      - ip route
+      - ip route rule
+      - ip route vrf
+      - ip service
+      - ip settings
+      - ip smb
+      - ip socks
+      - ip ssh
+      - ip tftp settings
+      - ip traffic-flow
+      - ip traffic-flow ipfix
+      - ip traffic-flow target
+      - ip upnp
+      - ip upnp interfaces
+      - ip vrf
+      - ipv6 address
+      - ipv6 dhcp-client
+      - ipv6 dhcp-server
+      - ipv6 dhcp-server option
+      - ipv6 firewall address-list
+      - ipv6 firewall filter
+      - ipv6 firewall mangle
+      - ipv6 firewall nat
+      - ipv6 firewall raw
+      - ipv6 nd
+      - ipv6 nd prefix
+      - ipv6 nd prefix default
+      - ipv6 route
+      - ipv6 settings
+      - mpls
+      - mpls interface
+      - mpls ldp
+      - mpls ldp accept-filter
+      - mpls ldp advertise-filter
+      - mpls ldp interface
+      - port firmware
+      - port remote-access
+      - ppp aaa
+      - ppp profile
+      - ppp secret
+      - queue interface
+      - queue simple
+      - queue tree
+      - queue type
+      - radius
+      - radius incoming
+      - routing bfd configuration
+      - routing bgp aggregate
+      - routing bgp connection
+      - routing bgp instance
+      - routing bgp network
+      - routing bgp peer
+      - routing bgp template
+      - routing filter
+      - routing filter community-list
+      - routing filter num-list
+      - routing filter rule
+      - routing filter select-rule
+      - routing id
+      - routing igmp-proxy
+      - routing igmp-proxy interface
+      - routing mme
+      - routing ospf area
+      - routing ospf area range
+      - routing ospf instance
+      - routing ospf interface-template
+      - routing ospf static-neighbor
+      - routing pimsm instance
+      - routing pimsm interface-template
+      - routing rip
+      - routing ripng
+      - routing rule
+      - routing table
+      - snmp
+      - snmp community
+      - system clock
+      - system clock manual
+      - system health settings
+      - system identity
+      - system leds settings
+      - system logging
+      - system logging action
+      - system note
+      - system ntp client
+      - system ntp client servers
+      - system ntp server
+      - system package update
+      - system resource irq rps
+      - system routerboard settings
+      - system scheduler
+      - system script
+      - system upgrade mirror
+      - system ups
+      - system watchdog
+      - tool bandwidth-server
+      - tool e-mail
+      - tool graphing
+      - tool graphing interface
+      - tool graphing resource
+      - tool mac-server
+      - tool mac-server mac-winbox
+      - tool mac-server ping
+      - tool netwatch
+      - tool romon
+      - tool sms
+      - tool sniffer
+      - tool traffic-generator
+      - user
+      - user aaa
+      - user group
+      - user settings
     # END PATH LIST
   data:
     description:
@@ -297,12 +307,12 @@ options:
     default: ignore
   handle_entries_content:
     description:
-      - For a single entry in O(data), this describes how to handle fields that are not mentioned
-        in that entry, but appear in the actual config.
+      - For a single entry in O(data), this describes how to handle fields that are not mentioned in that entry, but appear
+        in the actual config.
       - If V(ignore), they are not modified.
       - If V(remove), they are removed. If at least one cannot be removed, the module will fail.
-      - If V(remove_as_much_as_possible), all that can be removed will be removed. The ones that
-        cannot be removed will be kept.
+      - If V(remove_as_much_as_possible), all that can be removed will be removed. The ones that cannot be removed will be
+        kept.
       - Note that V(remove) and V(remove_as_much_as_possible) do not apply to write-only fields.
     type: str
     choices:
@@ -314,8 +324,8 @@ options:
     description:
       - How to handle values passed in for read-only fields.
       - If V(ignore), they are not passed to the API.
-      - If V(validate), the values are not passed for creation, and for updating they are compared to the value returned for the object.
-        If they differ, the module fails.
+      - If V(validate), the values are not passed for creation, and for updating they are compared to the value returned for
+        the object. If they differ, the module fails.
       - If V(error), the module will fail if read-only fields are provided.
     type: str
     choices:
@@ -328,9 +338,8 @@ options:
     description:
       - How to handle values passed in for write-only fields.
       - If V(create_only), they are passed on creation, and ignored for updating.
-      - If V(always_update), they are always passed to the API. This means that if such a value is present,
-        the module will always result in C(changed) since there is no way to validate whether the value
-        actually changed.
+      - If V(always_update), they are always passed to the API. This means that if such a value is present, the module will
+        always result in C(changed) since there is no way to validate whether the value actually changed.
       - If V(error), the module will fail if write-only fields are provided.
     type: str
     choices:
@@ -342,20 +351,18 @@ options:
   restrict:
     description:
       - Restrict operation to entries matching the following criteria.
-      - This can be useful together with O(handle_absent_entries=remove) to operate on a subset of
-        the values.
-      - For example, for O(path=ip firewall filter), you can set O(restrict[].field=chain) and
-        O(restrict[].values=input) to restrict operation to the input chain, and ignore the
-        forward and output chains.
+      - This can be useful together with O(handle_absent_entries=remove) to operate on a subset of the values.
+      - For example, for O(path=ip firewall filter), you can set O(restrict[].field=chain) and O(restrict[].values=input)
+        to restrict operation to the input chain, and ignore the forward and output chains.
     version_added: 2.18.0
 seealso:
   - module: community.routeros.api
   - module: community.routeros.api_facts
   - module: community.routeros.api_find_and_modify
   - module: community.routeros.api_info
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 ---
 - name: Setup DHCP server networks
   # Ensures that we have exactly two DHCP server networks (in the specified order)
@@ -410,43 +417,42 @@ EXAMPLES = '''
     data:
       - action: drop
         chain: input
-'''
+"""
 
-RETURN = '''
----
+RETURN = r"""
 old_data:
-    description:
-      - A list of all elements for the current path before a change was made.
-    sample:
-      - '.id': '*1'
-        actual-interface: bridge
-        address: "192.168.88.1/24"
-        comment: defconf
-        disabled: false
-        dynamic: false
-        interface: bridge
-        invalid: false
-        network: 192.168.88.0
-    type: list
-    elements: dict
-    returned: always
+  description:
+    - A list of all elements for the current path before a change was made.
+  sample:
+    - '.id': '*1'
+      actual-interface: bridge
+      address: "192.168.88.1/24"
+      comment: defconf
+      disabled: false
+      dynamic: false
+      interface: bridge
+      invalid: false
+      network: 192.168.88.0
+  type: list
+  elements: dict
+  returned: always
 new_data:
-    description:
-      - A list of all elements for the current path after a change was made.
-    sample:
-      - '.id': '*1'
-        actual-interface: bridge
-        address: "192.168.1.1/24"
-        comment: awesome
-        disabled: false
-        dynamic: false
-        interface: bridge
-        invalid: false
-        network: 192.168.1.0
-    type: list
-    elements: dict
-    returned: always
-'''
+  description:
+    - A list of all elements for the current path after a change was made.
+  sample:
+    - '.id': '*1'
+      actual-interface: bridge
+      address: "192.168.1.1/24"
+      comment: awesome
+      disabled: false
+      dynamic: false
+      interface: bridge
+      invalid: false
+      network: 192.168.1.0
+  type: list
+  elements: dict
+  returned: always
+"""
 
 from collections import defaultdict
 
@@ -470,6 +476,7 @@ from ansible_collections.community.routeros.plugins.module_utils._api_helper imp
     restrict_argument_spec,
     restrict_entry_accepted,
     validate_and_prepare_restrict,
+    value_to_str,
 )
 
 HAS_ORDEREDDICT = True
@@ -505,7 +512,7 @@ def find_modifications(old_entry, new_entry, path_info, module, for_text='', ret
         disabled_k = None
         if k.startswith('!'):
             disabled_k = k[1:]
-        elif v is None or v == path_info.fields[k].remove_value:
+        elif v is None or value_to_str(v) == value_to_str(path_info.fields[k].remove_value):
             disabled_k = k
         if disabled_k is not None:
             if disabled_k in old_entry:
@@ -515,7 +522,7 @@ def find_modifications(old_entry, new_entry, path_info, module, for_text='', ret
                     modifications['!%s' % disabled_k] = ''
                 del updated_entry[disabled_k]
             continue
-        if k not in old_entry and path_info.fields[k].default == v and not path_info.fields[k].can_disable:
+        if k not in old_entry and value_to_str(path_info.fields[k].default) == value_to_str(v) and not path_info.fields[k].can_disable:
             continue
         key_info = path_info.fields[k]
         if key_info.read_only:
@@ -529,7 +536,7 @@ def find_modifications(old_entry, new_entry, path_info, module, for_text='', ret
             if module.params['handle_write_only'] == 'create_only':
                 # do not update this value
                 continue
-        if k not in old_entry or old_entry[k] != v:
+        if k not in old_entry or value_to_str(old_entry[k]) != value_to_str(v):
             modifications[k] = v
             updated_entry[k] = v
     handle_entries_content = module.params['handle_entries_content']
@@ -572,15 +579,15 @@ def essentially_same_weight(old_entry, new_entry, path_info, module):
         disabled_k = None
         if k.startswith('!'):
             disabled_k = k[1:]
-        elif v is None or v == path_info.fields[k].remove_value:
+        elif v is None or value_to_str(v) == value_to_str(path_info.fields[k].remove_value):
             disabled_k = k
         if disabled_k is not None:
             if disabled_k in old_entry:
                 return None
             continue
-        if k not in old_entry and path_info.fields[k].default == v:
+        if k not in old_entry and value_to_str(path_info.fields[k].default) == value_to_str(v):
             continue
-        if k not in old_entry or old_entry[k] != v:
+        if k not in old_entry or value_to_str(old_entry[k]) != value_to_str(v):
             return None
     handle_entries_content = module.params['handle_entries_content']
     weight = 0
@@ -942,7 +949,7 @@ def sync_with_primary_keys(module, api, path, path_info, restrict_data):
                         index=index + 1,
                     )
                 )
-        pks = tuple(entry[primary_key] for primary_key in primary_keys)
+        pks = tuple(value_to_str(entry[primary_key]) for primary_key in primary_keys)
         if pks in new_data_by_key:
             module.fail_json(
                 msg='Every element in data must contain a unique value for {primary_keys}. The value {value} appears at least twice.'.format(
@@ -969,7 +976,7 @@ def sync_with_primary_keys(module, api, path, path_info, restrict_data):
     old_data_by_key = OrderedDict()
     id_by_key = {}
     for entry in old_data:
-        pks = tuple(entry[primary_key] for primary_key in primary_keys)
+        pks = tuple(value_to_str(entry[primary_key]) for primary_key in primary_keys)
         old_data_by_key[pks] = entry
         id_by_key[pks] = entry['.id']
     new_data = []
@@ -1022,14 +1029,14 @@ def sync_with_primary_keys(module, api, path, path_info, restrict_data):
     if module.params['ensure_order']:
         index_by_key = dict()
         for index, entry in enumerate(new_data):
-            index_by_key[tuple(entry[primary_key] for primary_key in primary_keys)] = index
+            index_by_key[tuple(value_to_str(entry[primary_key]) for primary_key in primary_keys)] = index
         for index, source_entry in enumerate(data):
-            source_pks = tuple(source_entry[primary_key] for primary_key in primary_keys)
+            source_pks = tuple(value_to_str(source_entry[primary_key]) for primary_key in primary_keys)
             source_index = index_by_key.pop(source_pks)
             if index == source_index:
                 continue
             entry = new_data[index]
-            pks = tuple(entry[primary_key] for primary_key in primary_keys)
+            pks = tuple(value_to_str(entry[primary_key]) for primary_key in primary_keys)
             reorder_list.append((source_pks, index, pks))
             for k, v in index_by_key.items():
                 if v >= index and v < source_index:
